Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
Guid string `json:"guid"`
Name string `json:"name"`
Environment map[string]interface{} `json:"environment_json"`
SpaceURL string `json:"space_url"`
SpaceData SpaceResource `json:"space"`
// contains filtered or unexported fields
}
type AppResource ¶
type AppResponse ¶
type AppResponse struct {
Count int `json:"total_results"`
Pages int `json:"total_pages"`
NextUrl string `json:"next_url"`
Resources []AppResource `json:"resources"`
}
type Client ¶
type Client struct {
Endpoint Endpoint
// contains filtered or unexported fields
}
Client used to communicate with Cloud Foundry
func (*Client) ListServices ¶
func (*Client) ListSpaces ¶
type Config ¶
type Config struct {
ApiAddress string
LoginAddress string
Username string
Password string
SkipSslValidation bool
HttpClient *http.Client
Token string
TokenSource oauth2.TokenSource
}
Config is used to configure the creation of a client
func DefaultConfig ¶
func DefaultConfig() *Config
DefaultConfig configuration for client Keep LoginAdress for backward compatibility Need to be remove in close future
type Endpoint ¶
type Endpoint struct {
DopplerEndpoint string `json:"doppler_logging_endpoint"`
LoggingEndpoint string `json:"logging_endpoint"`
AuthEndpoint string `json:"authorization_endpoint"`
TokenEndpoint string `json:"token_endpoint"`
}
func DefaultEndpoint ¶
func DefaultEndpoint() *Endpoint
type OrgResource ¶
type OrgResponse ¶
type OrgResponse struct {
Count int `json:"total_results"`
Pages int `json:"total_pages"`
Resources []OrgResource `json:"resources"`
}
type ServiceResource ¶
type ServiceResponse ¶
type ServiceResponse struct {
Count int `json:"total_results"`
Pages int `json:"total_pages"`
Resources []ServiceResource `json:"resources"`
}
type Space ¶
type Space struct {
Guid string `json:"guid"`
Name string `json:"name"`
OrgURL string `json:"organization_url"`
OrgData OrgResource `json:"organization"`
// contains filtered or unexported fields
}
type SpaceResource ¶
type SpaceResponse ¶
type SpaceResponse struct {
Count int `json:"total_results"`
Pages int `json:"total_pages"`
Resources []SpaceResource `json:"resources"`
}
Click to show internal directories.
Click to hide internal directories.